apt-atomic Cookbook
====================

Installs/Configures apt Atomic Vendor-Specific Repositories.

This cookbook installs & configures apt Atomic repositories per
http://ossec.github.io/downloads.html

Requirements
------------
- Chef 11 or higher
- Ruby 1.9 or higher (preferably from the Chef full-stack-installer)
- Network accessible package repositories
- Debian 7 or newer, or Ubuntu 12.04 or newer.
- [apt Cookbook](https://supermarket.chec.io/cookbooks/apt)

Attributes
----------
#### apt-atomic::default

The following attributes are set by default

```ruby
default['apt-atomic']['repos']['atomic']['managed'] = true
default['apt-atomic']['repos']['atomic']['repo_name'] = 'atomic'
default['apt-atomic']['repos']['atomic']['uri'] = "http://ossec.wazuh.com/repos/apt/debian"
default['apt-atomic']['repos']['atomic']['distribution'] = codename
default['apt-atomic']['repos']['atomic']['components'] = ['main']
default['apt-atomic']['repos']['atomic']['key'] = 'http://ossec.wazuh.com/repos/apt/conf/ossec-key.gpg.key'
default['apt-atomic']['repos']['atomic']['deb-src'] = false
```

## Recipes
- default - Walks through node attributes and feeds a apt_repository
- parameters. The following is an example a resource generated by the
- recipe during compilation.

```ruby
  apt_repository 'atomic' do
    uri			'http://ossec.wazuh.com/repos/apt/debian'
    distribution	codename
    components		['main']
    deb_src		false
    key			'http://ossec.wazuh.com/repos/apt/conf/ossec-key.gpg.key'
  end
```

## Usage Example
To disable the `atomic` repository through a Role or Environment definition

```
default_attributes(
  'apt' => {
    'atomic' => {
      'managed' => false
    }
  }
)
```

## More Examples
Point the base and debuginfo repositories at an internally hosted server.

```ruby
default['apt-atomic']['repos']['atomic']['managed'] = true
default['apt-atomic']['repos']['atomic']['repo_name'] = 'atomic'
default['apt-atomic']['repos']['atomic']['uri'] = "http://internal.example.com/repos/apt/debian"
default['apt-atomic']['repos']['atomic']['distribution'] = codename
default['apt-atomic']['repos']['atomic']['components'] = ['main']
default['apt-atomic']['repos']['atomic']['key'] = 'http://internal.example.com/repos/apt/debian//ossec-key.gpg.key'
default['apt-atomic']['repos']['atomic']['deb-src'] = false
```

## License & Authors
**Author:** Eric Renfro (<psi-jack@linux-help.org>)

**Copyright:** 2016, Linux-Help.org.

```
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
